@@ -1,7 +1,7 @@
 /*
  * Python Bindings for LZMA
  *
- * Copyright (c) 2004-2014 by Joachim Bauch, mail@joachim-bauch.de
+ * Copyright (c) 2004-2015 by Joachim Bauch, mail@joachim-bauch.de
  * 7-Zip Copyright (C) 1999-2010 Igor Pavlov
  * LZMA SDK Copyright (C) 1999-2010 Igor Pavlov
  *
@@ -46,10 +46,12 @@ pylzma_comp_compress(CCompressionObject *self, PyObject *args)
 {
     PyObject *result = NULL;
     char *data;
-    int length, bufsize=BLOCK_SIZE, res;
+    PARSE_LENGTH_TYPE length;
+    PY_LONG_LONG bufsize=BLOCK_SIZE;
+    int res;
     size_t before;
     
-    if (!PyArg_ParseTuple(args, "s#|i", &data, &length, &bufsize))
+    if (!PyArg_ParseTuple(args, "s#|L", &data, &length, &bufsize))
         return NULL;
     
     if (!MemoryInOutStreamAppend(&self->inStream, (Byte *) data, length)) {
