@@ -39,6 +39,12 @@ except NameError:
         l.sort()
         return l
 
+try:
+    xrange
+except NameError:
+    # Python 3.x
+    xrange = range
+
 if sys.version_info[:2] < (3, 0):
     def bytes(s, encoding):
         return s
@@ -275,12 +281,34 @@ class Test7ZipFiles(unittest.TestCase):
     def test_github_33(self):
         fp = self._open_file(os.path.join(ROOT, 'data', 'github_33.7z'), 'rb')
         archive = Archive7z(fp, password='abc')
-        # Archive only creates an empty file (which gets filtered).
-        self.assertEqual(archive.getnames(), [])
+        # Archive only contains an empty file.
+        self.assertEqual(archive.getnames(), ['successs.txt'])
         self.assertEqual(archive.header.files.numfiles, 1)
         self.assertEqual([x['filename'] for x in archive.header.files.files], [u'successs.txt'])
         cf = archive.getmember('successs.txt')
-        self.assertEqual(cf, None)
+        self.assertNotEqual(cf, None)
+        data = cf.read()
+        self.assertEqual(len(data), cf.uncompressed)
+        self.assertEqual(len(data), 0)
+        self._test_decode_all(archive)
+
+    def test_github_43(self):
+        # test loading of lzma2 compressed files
+        self._test_archive('github_43.7z')
+
+    def test_github_43_provided(self):
+        # test loading file submitted by @mikenye
+        fp = self._open_file(os.path.join(ROOT, 'data', 'test-issue-43.7z'), 'rb')
+        archive = Archive7z(fp)
+        self.assertEqual(sorted(archive.getnames()), ['blah.txt'] + ['blah%d.txt' % x for x in xrange(2, 10)])
+        self._test_decode_all(archive)
+
+    def test_github_53(self):
+        # test loading file submitted by @VinylChloride
+        fp = self._open_file(os.path.join(ROOT, 'data', 'github_53.7z'), 'rb')
+        archive = Archive7z(fp, password='1234')
+        self.assertEqual(sorted(archive.getnames()), ['test/test/archive7zip.py', 'test/test/mainPrg.py'])
+        self._test_decode_all(archive)
 
 def suite():
     suite = unittest.TestSuite()
